mercurial/commands.py
changeset 3913 283ee8971570
parent 3900 2b3175acb653
child 3914 3c82ab166eea
--- a/mercurial/commands.py
+++ b/mercurial/commands.py
@@ -339,7 +339,7 @@ def bundle(ui, repo, fname, dest=None, *
     changegroup.writebundle(cg, fname, "HG10BZ")
 
 def cat(ui, repo, file1, *pats, **opts):
     """output the latest or given revisions of files
 
     Print the specified files as they were at the given revision.
     If no revision is given then working dir parent is used, or tip
@@ -1741,9 +1741,11 @@ def log(ui, repo, *pats, **opts):
                 count += 1
 
 def manifest(ui, repo, rev=None):
-    """output the latest or given revision of the project manifest
+    """output the current or given revision of the project manifest
 
     Print a list of version controlled files for the given revision.
+    If no revision is given then working dir parent is used, or tip
+    if no revision is checked out.
 
     The manifest is the list of files being version controlled. If no revision
     is given then the first parent of the working directory is used.
@@ -339,7 +339,7 @@ def bundle(ui, repo, fname, dest=None, *
 
 def cat(ui, repo, file1, *pats, **opts):
-    """output the latest or given revisions of files
+    """output the current or given revision of files
 
     Print the specified files as they were at the given revision.